# WebHookLogModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**web_hook_name** | **str, none_type** |  | [optional] 
**event_type** | [**WebHookEventTypeModel**](WebHookEventTypeModel.md) |  | [optional] 
**web_hook_id** | **str** |  | [optional] 
**request_body** | **str, none_type** |  | [optional] 
**request_meta** | **str, none_type** |  | [optional] 
**response_status_code** | **int** |  | [optional] 
**response_body** | **str, none_type** |  | [optional] 
**response_meta** | **str, none_type** |  | [optional] 
**project_id** | **str** |  | [optional] 
**url** | **str, none_type** |  | [optional] 
**request_type** | [**RequestTypeModel**](RequestTypeModel.md) |  | [optional] 
**created_date** | **datetime, none_type** |  | [optional] 
**modified_date** | **datetime, none_type** |  | [optional] 
**created_by_id** | **str** |  | [optional] 
**modified_by_id** | **str, none_type** |  | [optional] 
**id** | **str** |  | [optional] 
**is_deleted** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


